@@ -39,4 +39,4 @@ def test_docstrings(module):
 	print(indent(stdout.getvalue(), "  "))
 
 	if runner.failures:
-		pytest.fail(msg=f"{runner.failures} tests failed")
+		pytest.fail(f"{runner.failures} tests failed")
